/***
Purpose: Construct county level covariates file
Created: BG 2020-4-8
***/

*-------------------------------------------------------------------------------------------------
* Define Census regions for each state
*-------------------------------------------------------------------------------------------------

import excel "input/state-geocodes-v2017.xlsx", sheet("CODES14") firstrow clear
rename *, lower

* Convert to numeric
destring region division statefips, replace 

* Drop aggregate regions
drop if statefips==0
rename statefips state
drop name
tempfile regions
save `regions'

*-------------------------------------------------------------------------------------------------
* Merge to OI county covariates
*-------------------------------------------------------------------------------------------------

use "input/cty_covariates.dta", clear

* This eliminates statefips=72 Puerto Rico
merge m:1 state using `regions', assert(1 3) keep(3) nogen

* Build fips code
tostring state, gen(st) format(%02.0f)
tostring county, gen(cty) format(%03.0f)
g fips=st+cty
destring fips, replace
drop state county st cty
order fips

*-------------------------------------------------------------------------------------------------
* Merge to OI health county covariates
*-------------------------------------------------------------------------------------------------

rename fips cty
merge 1:1 cty using "input/health_ineq_online_table_12", keep(1 3) nogen ///
	keepusing(cur_smoke* bmi_obese* exercise* puninsured2010 reimb_penroll_adj10 mort_30day_hosp_z ///
	adjmortmeas_amiall30day adjmortmeas_chfall30day adjmortmeas_pnall30day diab_hemotest_10)
rename cty fips 

* Output 
compress
save "output/cty_covariates_with_region", replace
