library(dplyr)
library(readr)
library(usmap)
library(purrr)

county_raw <-read_csv("input/nyt_covid_us_counties.csv")
county_daily <- read_csv("input/county_day_data.csv")

nyc_counties <- data.frame(county = c('New York County', 'Kings County', 'Bronx County', 
                                         'Richmond County', 'Queens County'))

nyc_counties %>% mutate(county_fips = fips(state = "NY", county), state = 'New York') -> nyc_counties

county_daily %>%
  mutate(county_fips = as.character(FIPS)) %>%
  filter(county_fips %in% nyc_counties$county_fips) %>%
  distinct(county_fips, pop) %>%
  mutate(share = pop/sum(pop)) %>%
  left_join(nyc_counties, by = 'county_fips') -> nyc_county_pops

county_raw %>%
  filter(county == 'New York City') %>%
  select(date, cases, deaths) -> nyc_raw

nyc_raw %>%
  merge(nyc_county_pops) %>%
  mutate(cases = cases*share, deaths = cases*share) %>%
  select(-one_of(c('share', 'pop'))) -> nyc_data

county_raw %>%
  filter(county != 'New York City') %>%
  rename(county_fips = fips) %>%
  bind_rows(nyc_data) %>%
  mutate(state_fips = substr(county_fips, 1, 2)) -> county_covid_data

write_csv(county_covid_data, 'output/county_case_death_data.csv')
