/***
Purpose: Prepare Facteus debit card data for merge to base file
Created: BG 2020-4-12
***/

*-------------------------------------------------------------------------------------------------
* Prepare zip-county crosswalk 
*-------------------------------------------------------------------------------------------------

import excel "input/ZIP_COUNTY_122019.xlsx", sheet("zip_county_122019") firstrow clear
rename *, lower

* Reduce to one row per zip code by assigning the ZIP to the county with the largest share of 
*	of addresses from that zip
bysort zip (tot_ratio): keep if _n==_N
isid zip

* Convert to numeric zip code
destring county, gen(fips)
destring zip, replace 

* Output a temporary file
keep zip fips
save "output/zip_cty_cw", replace

*-------------------------------------------------------------------------------------------------
* Clean the Facteus data
*-------------------------------------------------------------------------------------------------

import delimited "output/facteus_precleaned.csv", clear 
	
* Merge on counties 
merge m:1 zip using "output/zip_ctY_cw", nogen keep(3)

* Collapse to county level
collapse (sum) num_transactions total_spend, by(fips date) fast

* Generate date variable
rename date tmp
g date=date(tmp, "YMD")
format date %td

* Output
keep fips date num_transactions total_spend
sort fips date
compress
save "output/facteus_county_daily", replace

*-------------------------------------------------------------------------------------------------
* Clean the Homebase data
*-------------------------------------------------------------------------------------------------

import delimited "output/homebase_by_county.csv", clear varnames(1)
rename county_code fips

* Generate date variable 
g date=date(event_date, "YMD")
format date %td

* Output
keep date fips count_hours_pos sum_hours sum_wages
compress
save "output/homebase_by_county_cleaned", replace
