rm(list = ls())
CRAN_packages <- c("dplyr", "readr", "magrittr", "stringr", "tidyr", "lubridate")
lapply(CRAN_packages, require, character.only = TRUE)

n_max <- Inf # Maximum number of observations to load (decrease for testing purposes)

col_types <-  cols_only(event_date = col_date(format = ""),
                        location_id = "d",
                        user_id = "d",
                        county_code = "d",
                        industry    = "c",
                        avg_hourly_wage_rate = "d",
                        total_wages_earned = "d",
                        hours_worked = "d")

groupings <- list("totals"        = quos(event_date),
                  "by_county"     = quos(event_date, county_code),
                  "by_county_ind" = quos(event_date, county_code, industry))

historical_dir <- "external/homebase_historical"
daily_updates_dir <- "external/homebase_daily_updates"
historical_files <- paste(historical_dir, list.files(historical_dir), sep="/")
daily_updates_files <- paste(daily_updates_dir, list.files(daily_updates_dir), sep="/")
files <- c(historical_files, daily_updates_files)

combined <- lapply(groupings, function(x) {return(NULL)})
existing_keys <- NULL

for (file in files) {
  print(file)
  ungrouped <- file %>% 
    read_csv(n_max=n_max, na = c("", "NA", "\\N"),
             col_types=col_types) %>%
    filter(year(event_date)>=2020 & !is.na(county_code)) %>%
    mutate(hours_pos = (hours_worked>0), hours_nm = !is.na(hours_worked), 
           wages_tot_nm = !is.na(hours_worked))
  
  
  #Check to see if duplicates exist by event_dateXlocation_idXuser_id (these should identify unique observation)
  n_original <- ungrouped %>% nrow()
  if (!is.null(existing_keys)) {
    ungrouped %<>% anti_join(existing_keys, by=c("event_date", "location_id", "user_id"))
    n_new <- ungrouped %>% nrow()
    if (n_new!=n_original) print(sprintf('Deleted %d duplicate keys', n_original-n_new))
  }
  existing_keys <- ungrouped %>%
    select(event_date, location_id, user_id) %>%
    distinct() %>%
    bind_rows(existing_keys)
  
  for (group_n in seq_along(groupings)) {
    group_nm <- names(groupings)[group_n]
    groups <- groupings[[group_nm]]
    new_rows <- ungrouped %>%
      group_by(!!! groups) %>%
      summarize(count_tot = n(), 
                count_hours_pos = sum(hours_worked>0, na.rm=TRUE),
                count_hours_nm = sum(!is.na(hours_worked)), 
                count_wages_tot_nm =  sum(!is.na(total_wages_earned)),
                count_wages_avg_nm = sum(!is.na(avg_hourly_wage_rate)),
                sum_hours = sum(hours_worked, na.rm=TRUE),
                sum_wages = sum(total_wages_earned, na.rm=TRUE),
                mean_wages_avg = mean(avg_hourly_wage_rate, na.rm=TRUE)) %>%
      ungroup() 
    combined[[group_nm]] %<>% bind_rows(new_rows)
  }
}

for (group_n in seq_along(groupings)) {
  group_nm <- names(groupings)[group_n]
  groups <- groupings[[group_n]]
  combined[[group_nm]] %<>% group_by(!!! groups) %>%
    mutate(mean_wages_avg = mean_wages_avg*count_wages_avg_nm/sum(count_wages_avg_nm,
                                                                         na.rm=TRUE)) %>%
    summarize_all(sum, na.rm=TRUE) %>% ungroup() %>%
    complete(!!! groups) %>% arrange(!!! groups)
  
  names_to_0 <- combined[[group_nm]] %>%
    select(starts_with("count_"), starts_with("sum_")) %>% names()
  to_0 <- as.list(rep.int(0, times=length(names_to_0)))
  names(to_0) <- names_to_0
  combined[[group_nm]] %<>% replace_na(to_0) %>% replace_na(list("mean_wages_avg" = NaN))
  combined[[group_nm]] %>% write_csv(sprintf("output/homebase_%s.csv", group_nm))
}


