CRAN_packages <- c("dplyr", "readr", "magrittr", "tidyr")
lapply(CRAN_packages, require, character.only = TRUE)

#This file combines multiple cuts of the Facteus transactions dataset, which occasionally overlap but which are
# necessary to combine in order to produce the full Facteus time series available.

main <- function () {
  #List of variable names and types in raw files
  to_load <- list("date"      = col_date(format = ""),
                  "zip"       = "c",
                  "num_cards" = "d",
                  "num_transactions" = "d",
                  "total_spend" = "d")
  #List of files containing different cuts of the data
  files <- c("cut-1-daily-spend-by-zip-20170101-20200417.csv.gz", 
             "cut-1-daily-spend-by-zip-20200417-20200617-0.csv.gz",
             "cut-1-daily-spend-by-zip-20200618-20200707-0.csv.gz",
             "cut-1-daily-spend-by-zip-20200708-20200806-0.csv.gz",
             "cut-1-daily-spend-by-zip-20200808-20200814-0.csv.gz", #08/07/2020 is missing from the Facteus data
             "cut-1-daily-spend-by-zip-20200814-20200820-0.csv.gz",
             "cut-1-daily-spend-by-zip-20200821-20200827-0.csv.gz") 
  data <- NULL #Combine data cuts in this object
  for (file_nm in files) {
    print(file_nm)
    new <- read_csv(sprintf("external/%s", file_nm), 
                    col_names=c("date", "zip", "num_cards", "num_transactions", "total_spend"),
                    col_types = do.call(cols_only, to_load)) %>%
      filter(date>="2020-01-01")
    first_new_dt <- min(new$date)
    if (!is.null(data)) data %<>% filter(date<first_new_dt) #When cuts overlap, user newer cut
    data %<>% bind_rows(new)
    new <- NULL
  }
  data %>% 
    complete(date, zip,
             fill = list("num_cards" = 0, "num_transactions" = 0, "total_spend" = 0)) %>% #Fill missing dateXzip combinations
    write_csv("output/facteus_precleaned.csv")
  
  return(NULL)
}

main()