# Some sources used:
# https://kite.com/python/answers/how-to-convert-a-dictionary-to-a-numpy-array-in-python
# https://stackoverflow.com/questions/51186619/convert-list-of-dictionaries-to-dataframe-with-one-column-for-keys-and-one-for-v/51190541

from __future__ import division
import pandas as pd
import numpy as np
import ast
import csv
import gzip
import zipfile 
import io
import os
import glob
import re
#Get series of 2020 weeks
base_week = "2020-01-27"
times = pd.date_range(base_week, "2020-08-24", freq='W-MON') #Main time series used in estimation
times = times.append(pd.date_range("2019-12-30", pd.to_datetime(base_week) - pd.DateOffset(weeks=1), freq='W-MON')) #Fill in start of 2020
times = times.astype(str).tolist()

#Load commonly used files
poi_county   = pd.read_csv("output_local/placeid_county.csv", encoding = 'utf-8', dtype={'state_fips': str, 'county': str})
for t in times:
    print(t)
    if t<"2020-06-15":
        parts = ["external/Weekly Patterns/main-file/%s-weekly-patterns.csv.gz" % t]
    else:
        t_dt = pd.to_datetime(t) + pd.DateOffset(days=9) #Delivery date occurs 9 days after start of week
        parts = glob.glob("external/Weekly Patterns Continued/patterns/{delivery_dt}/*/*.csv.gz".format(delivery_dt = t_dt.strftime('%Y/%m/%d')))
        assert len(parts)==4
    temp = pd.DataFrame()
    for part in parts:
        temp = temp.append(pd.read_csv(part, escapechar = "\\", encoding = 'utf-8', compression='gzip'))

    # Get POI visits by day
    temp['visits_by_day'] = temp['visits_by_day'].apply(lambda x: ast.literal_eval(x))
    newvalues = np.dstack((
                    np.repeat(temp.safegraph_place_id.values, list(map(len, temp.visits_by_day))),
                    np.tile(range(1, len(temp.visits_by_day.values[0]) + 1), len(temp.visits_by_day)), 
                    np.concatenate(temp.visits_by_day.values)
    )) # https://stackoverflow.com/questions/53218931/how-to-unnest-explode-a-column-in-a-pandas-dataframe
    temp_daily = pd.DataFrame(data = newvalues[0], columns = ['safegraph_place_id', 'day', 'visits'])
    del temp, newvalues

    # Merge on county, restrict to POIs we mapped to counties
    temp_daily        = temp_daily.merge(poi_county, how = 'inner')

    # Aggregate by county-day and save
    county_daily_poi_visits = temp_daily.groupby(['county', 'day'])['visits'].sum().reset_index()
    county_daily_poi_visits.to_csv("output_local/county_daily_%s.csv" % t, encoding = 'utf-8', index=False)
    del county_daily_poi_visits, temp_daily