CRAN_packages <- c("readr", "dplyr", "lubridate", "magrittr", "tidyr", "stringr")
lapply(CRAN_packages, require, character.only = TRUE)

# https://stackoverflow.com/questions/51295402/r-on-macos-error-vector-memory-exhausted-limit-reached
# Implement following:
#   `cd ~`
#   `touch .Renviron`
#   `open .Renviron`
# Then add the following: `R_MAX_VSIZE=100Gb`
Sys.setenv('R_MAX_VSIZE'=32000000000)

main <- function(){
  # Dates
  dates <- seq(ymd("2020-01-27"), ymd("2020-08-24"), "1 week") #Weekly dates starting with beginning of study
  dates_plus   <- seq(ymd("2019-12-30"), max(dates), "1 week")

  # Clean dataset by countyXday
  clean_data(out_filename = "county_day_data", input_data = "county_daily",
             dates = dates_plus, geo_vars = "county", time_var = "day",
             relative_to = dates[1], 
             min_time = as.numeric(ymd("2020-01-01")-dates[1]))
}

clean_data <- function(out_filename, input_data, dates, geo_vars, time_var, 
                       relative_to = NULL, min_time = -Inf) {
  if (is.null(relative_to)) relative_to <- dates[1]
  year <- year(relative_to)
  geo <- ifelse("county" %in% geo_vars, "county", NA)
  geodate <- c(geo_vars, "date")
  
  
  data <- load_and_rbind(input_data, dates) %>%
    mutate(date = as.Date(date) + day - 1) %>%
    select(-day) %>%
    complete(nesting(!!! syms(geo_vars)), date, fill=list("visits" = 0))
  
  data %<>% mutate(state_fips = str_sub(county, 1, 2))
  
  # Get relative date
  data %<>% mutate(day = as.numeric(date - as.Date(relative_to)))
  data %<>% rename(time = {{time_var}}) %>%
    filter(time >= min_time)
  
  # Add Open Census County Controls and Vote Share
  demos <- read_csv(sprintf("output_local/%s_demographics.csv", geo))
  data %<>% merge(demos)
  
  # Drop Alaska due to district-level voting issue
  data %<>% filter(state_fips != "02") #Already dropped Alaska when running add_county_controls()
  
  # Drop Kansas City due to unavailable Covid case data: https://github.com/nytimes/covid-19-data
  kc   <- c("29037", "29047", "29095", "29165")
  data %<>% filter(!(county %in% c(kc))) 
  
  data %<>% mutate(county = as.numeric(county)) %>% rename(FIPS=county)
  
  # Save
  write_csv(data, sprintf("output/%s.csv", out_filename))
}

load_and_rbind <- function(prefix, dates) {
  data  <- NULL
  for (i in seq_along(dates)) {
    temp <- read_csv(sprintf("output_local/%s_%s.csv", prefix, dates[i])) %>%
      mutate(date = dates[i])
    
    data %<>% bind_rows(temp)
  }
  return(data)
}

# RUN
main()
