/***
Purpose: Build descriptive figures on quarantining policies and social distancing behaviors 
Created: BG 2020-4-3
***/
adopath + "../lib/ado"

global figext pdf
global titlesize=0.8
set scheme bg_5by8

use "input/event_study_input_data", clear

*-------------------------------------------------------------------------------------------------
* Other figs
*-------------------------------------------------------------------------------------------------

bysort fips: gen first_row = (_n == 1) & !missing(fips)

* Histogram of date of first order
twoway ///
	hist first_day_order_sip if first_row==1, freq fcolor("scheme p1") lcolor("scheme p1") barwidth(0.7) || ///
	hist first_day_order_bus if first_row==1, freq fcolor("orange%85") lcolor("scheme p2") barwidth(0.75) ///
	ytitle("Number of Counties") ylabel(, gmax) ///
	xtitle("Date of Order") xlabel(, format(%tdMon_dd)) ///
	legend(order(1 "Stay-at-home order" 2 "Business closing order")) ///
	title("")
graph export "output/hist_first_order_date_noweight.${figext}", replace

* Plot probability of having a lockdown relative to virus arrival date
g plot_rel_virus=date-date_virus_arrives
binscatter order_sip plot_rel_virus if inrange(plot_rel_virus, -21, 21) [w=pop], discrete linetype(none) ///
	msymbol(smcircle) mcolor("scheme p1") ///
	xtitle("Days Relative to 0.01% of Population Infected") ///
	ytitle("Fraction With a Stay-at-Home Order") ylabel(, gmax format(%03.1f)) ///
	title("", size(*${titlesize}))
graph export "output/lockdown_by_virus_arrival.${figext}", replace

* Browse reopening policies by state
bysort statename: g first_state_row = (_n==1) & statename!=""

* Distribution of reopening dates across states
twoway ///
	hist date_reopen if first_state_row==1, freq discrete ///
		fcolor("scheme p1") lcolor("scheme p1") barwidth(0.7) ///
		ytitle("Number of States") ///
		xtitle("") xlabel(#8, format(%tdMon_dd)) ///
		title("") 
graph export "output/hist_reopen_dates.${figext}", replace
