library(readstata13)
library(ggplot2)
library(dplyr)

data_raw <- read.dta13("input/event_study_input_data.dta")
data_raw <- data_raw[data_raw$date < "2020-06-01",]
data <- data_raw %>%
  mutate(order_dt = as.Date(first_day_order_sip),
         week = date - (as.numeric(date - as.Date("2020/01/29")) %% 7), 
         Timing = ifelse(is.na(order_dt), "No Order",
                         ifelse(order_dt <= "2020/03/25", "Early Order",
                                "Late Order")),
         visits = as.double(visits)) %>% #Avoid integer overflow issue when computing weighted mean below
  group_by(Timing, week) %>%
  filter(week >= "2020/01/29") %>%
  summarize(log_visits = log(weighted.mean(visits, pop)),
            log_new_cases = log(weighted.mean(new_cases, pop)),
            .groups = "drop_last") %>%
  mutate(log_visits_norm = log_visits - sum(log_visits*(week=="2020/01/29"), na.rm=T),
         log_new_cases_norm = log_new_cases - sum(log_new_cases*(week=="2020/03/25"), na.rm=T)) %>%
  ungroup() %>%
  mutate(log_new_cases = ifelse(week>="2020/03/11", log_new_cases, NA),
         log_new_cases_norm = ifelse(week>="2020/03/11", log_new_cases_norm, NA))

# Plot average daily visits, in logs and normalized to 1/29/2020
p1 <- data %>% ggplot(aes(x = week, y = log_visits_norm, col = Timing, lty = Timing)) +
  geom_line() + theme_bw() + ylab("Normalized Log(Visits)") + xlab("Week") +
  geom_vline(xintercept = as.Date("2020/03/25"), lty = 3, color = "grey") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text=element_text(size = 11), axis.text.x = element_text(angle = -60, hjust = 0)) # https://stackoverflow.com/questions/11748384/formatting-dates-on-x-axis-in-ggplot2
ggsave(filename="output/by_order_timing_visits_norm.pdf", plot=p1, height=5, width = 10)

# Plot average daily new cases, in logs and normalized to 3/25/2020
p3 <- data %>% ggplot(aes(x = week, y = log_new_cases_norm, col = Timing, lty = Timing)) +
  geom_line() + theme_bw() + ylab("Normalized Log(New Cases)") + xlab("Week") +
  geom_vline(xintercept = as.Date("2020/03/25"), lty = 3, color = "grey") + 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text=element_text(size = 11), axis.text.x = element_text(angle = -60, hjust = 0)) # https://stackoverflow.com/questions/11748384/formatting-dates-on-x-axis-in-ggplot2
ggsave(filename="output/by_order_timing_new_cases_norm.pdf", plot=p3, height=5, width = 10)