/***
Purpose: Build figures produced in R in Stata to match formatting 
Created: BG 2020-5-18
***/

adopath + "../lib/ado"
set scheme bg_5by8

*-------------------------------------------------------------------------------------------------
* Billy's decompnosition figure for distacning and econ outcomes
*-------------------------------------------------------------------------------------------------

import delimited "output/decomp/data_for_decomp_plot.csv", clear
keep if outcome !="Contact Rate"

* Generate standard error bars
g top=mandatory_share+1.96*mandatory_share_se
g bot=mandatory_share-1.96*mandatory_share_se

* Generate variables for plotting
g x=1 if outcome=="Visits"
replace x=2 if outcome=="Wages"
replace x=3 if outcome=="Employment"

* Shift the non-primary specs over
replace x=x-.1 if pretty_spec=="SIP"
replace x=x+.1 if pretty_spec=="Both"

* Plot 
twoway ///
	scatter mandatory_share x if pretty_spec=="SIP", mcolor("scheme p1") || ///
	rcap top bot x if pretty_spec=="SIP", lcolor("scheme p1") || ///
	scatter mandatory_share x if pretty_spec=="Business", mcolor("scheme p2") msymbol(Oh) || ///
	rcap top bot x if pretty_spec=="Business", lcolor("scheme p2") ///
	legend(row(1) order(1 "Stay-at-Home" 3 "Business")) /// 
	xtitle("") xscale(range(0.4 3.6)) ///
	xlabel(1 "POI Visits" 2 "Wages" 3 "Employment") ///
	ytitle("Policy-Induced Share") ylabel(, gmax format(%03.2f)) ///
	title("")
graph export "output/decomp/frac_mandatory_dist_econ.pdf", replace

*-------------------------------------------------------------------------------------------------
* Decomposition for health outcomes
*-------------------------------------------------------------------------------------------------

import delimited "output/decomp/data_for_decomp_plot.csv", clear
keep if outcome =="Contact Rate"

* Generate standard error bars
g top=mandatory_share+1.96*mandatory_share_se
g bot=mandatory_share-1.96*mandatory_share_se

* Generate variables for plotting
g x=1 if gamma=="1/6"
replace x=2 if gamma=="1/9"
replace x=3 if gamma=="1/12"
replace x=x-.1 if r0=="2.7"
replace x=x+.1 if r0=="3.3"

* Plot 
twoway ///
	scatter mandatory_share x if r0=="2.7", mcolor("0 0 0") || ///
	rcap top bot x if r0=="2.7", lcolor("0 0 0") || ///
	scatter mandatory_share x if r0=="3", mcolor("30 150 30") || ///
	rcap top bot x if r0=="3", lcolor("30 150 30") || ///
	scatter mandatory_share x if r0=="3.3", mcolor("30 30 150") msymbol(Oh) || ///
	rcap top bot x if r0=="3.3", lcolor("30 30 150")  ///
	legend(row(1) order(1 "R{subscript:0}=2.7" 3 "R{subscript:0}=3" 5 "R{subscript:0}=3.3")) ///
	xtitle("Contact Rate ({&beta})") xscale(range(0.4 3.6)) ///
	xlabel(1 "{&gamma}=1/6" 2 "{&gamma}=1/9" 3 "{&gamma}=1/12") ///
	ytitle("Policy-Induced Share") ylabel(, gmax format(%02.1f)) ///
	title("")
graph export "output/decomp/frac_mandatory_contact_rate.pdf", replace

