

*-------------------------------------------------------------------------------------------------
* Construct a program that computes the share variables
*-------------------------------------------------------------------------------------------------
cap program drop compute_shares
program define compute_shares 
	* Create Share Variables
	foreach v of varlist pop_age_65plus-pop_age_under18 {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_age_denom
		drop `v'
	}

	foreach v of varlist pop_race_white-pop_race_other {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_race_denom
		drop `v'
	}

	foreach v of varlist pop_hispanic {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_hispanic_denom
		drop `v'
	}

	foreach v of varlist pop_educ_bachelors_plus {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_educ_denom
		drop `v'
	}

	foreach v of varlist pop_degree_science_engineering-pop_degree_arts_humanities {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_degree_denom
		drop `v'
	}

	foreach v of varlist pop_poverty {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_poverty_denom
		drop `v'
	}

	foreach v of varlist pop_occ_man_bus_sci_art-pop_occ_production_transport {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_occ_denom
		drop `v'
	}

	foreach v of varlist pop_occd_mgmt-pop_occd_material {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_occd_denom
		drop `v'
	}

	foreach v of varlist pop_insurance_insured {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_insurance_denom
		drop `v'
	}

	foreach v of varlist pop_commute_auto-pop_commute_non {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_commute_denom
		drop `v'
	}

	foreach v of varlist pop_householdsize_1-pop_householdsize_6plus {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_householdsize_denom
		drop `v'
	}

	foreach v of varlist pop_vehicle_gtreq1 {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_vehicle_denom
		drop `v'
	}

	foreach v of varlist pop_home_renter {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_home_denom
		drop `v'
	}

	foreach v of varlist pop_urban {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_urban_denom
		drop `v'
	}

	foreach v of varlist pop_enroll_undergrad pop_enroll_grad_professional {	
		local temp = substr("sh_`v'", 1, 25)
		gen `temp' = `v' / pop_enroll_denom
		drop `v'
	}

end

*-------------------------------------------------------------------------------------------------
* Construct a program that computes value add
*-------------------------------------------------------------------------------------------------

cap program drop val_add
program define val_add
	syntax [ , vars(varlist) name(string) unit(string)]
	local coef_vars : colfullnames e(b)
	
	gen `name'_val_add = 0
	foreach v in `vars' {
		if regexm("`coef_vars'", "`v'") { 
			local coef = _b[`v']
			di `coef'
			replace `name'_val_add = `name'_val_add + `coef' * `v' 
		}
	}
	bysort `unit': egen temp = mode(`name'_val_add)
	replace `name'_val_add = temp
	drop temp
end

cap program drop create_value_add
program define create_value_add
	syntax [ , unit(string)]

	val_add, vars(log_pop log_pop_density sh_pop_urban) name("density") unit(`unit')
	val_add, vars(summer_tmmx winter_tmmx) name("climate") unit(`unit')
	val_add, vars(sh_pop_commute_auto log_inter_flights) name("transport") unit(`unit')
	val_add, vars(r_share) name("party") unit(`unit')
	val_add, vars(sh_pop_race_black sh_pop_race_white sh_pop_hispanic sh_pop_race_asian sh_pop_race_other) name("race") unit(`unit')
	val_add, vars(sh_pop_educ_bachelors) name("education") unit(`unit')
	val_add, vars(sh_pop_age_65plus sh_pop_age_under18) name("demographics") unit(`unit')
	
	* All covariates
	predict lasso_pred_fe, xb
	bysort `unit': egen temp = mode(lasso_pred_fe)
	replace lasso_pred_fe = temp
	drop temp

end

*-------------------------------------------------------------------------------------------------
* Construct a program that makes additive decomposition tables
*-------------------------------------------------------------------------------------------------
cap program drop make_add_decomp_tables
program define make_add_decomp_tables
	syntax [ , unit(string)]
	
	xtset `unit' date

	* Subtract Timing/Date FEs
	gen log_beta_timing = log_beta_t_6 - date_val_add

	* Subtract policy (e.g., Turn Off Everywhere)
	gen log_beta_policy_prop = log_beta_t_6 - ${Lambda_0} * (${poi_effect} * treat_on)

	* Subtract FEs
	gen log_beta_fe_full = log_beta_t_6 - fe

	* Subtract Predicted FEs
	gen log_beta_fe_pred  = log_beta_t_6 - lasso_pred_fe

	* Subtract pop density
	gen log_beta_pop_density = log_beta_t_6 - density_val_add

	* Subtract race
	gen log_beta_race = log_beta_t_6 - race_val_add

	* Subtract partisanship
	gen log_beta_party = log_beta_t_6 - party_val_add

	* Subtract climate
	gen log_beta_climate = log_beta_t_6 - climate_val_add

	* Subtract transport
	gen log_beta_transport = log_beta_t_6 - transport_val_add
	
	* Subtract education
	gen log_beta_education = log_beta_t_6 - education_val_add

	* Subtract demographics
	gen log_beta_demographics = log_beta_t_6 - demographics_val_add
	
	* Create Table
	local outcomes log_beta_t_6 log_beta_t_6_const log_beta_policy_prop log_beta_timing log_beta_fe_full log_beta_fe_pred log_beta_pop_density log_beta_climate log_beta_transport log_beta_race log_beta_party log_beta_education log_beta_demographics
	
	* Overall
	preserve
	keep if date >= mdy(3,15,2020) & date < mdy(5,1,2020)

	bysort `unit': egen mean_log_beta = mean(log_beta_t_6) 
	hist mean_log_beta
	su mean_log_beta if date == mdy(4,30,2020), d
	gen over = (mean_log_beta > `r(p50)')

	collapse (mean) `outcomes' delta_log_visits *fe log_pop_density, by(over)

	tsset over
	foreach v of varlist `outcomes' {
		gen d_`v' = `v' - l.`v'
	}
	keep d_*
	keep if _n == 2

	outsheet using "output/additive_decomposition.txt", replace

	restore

	* Top 25/Bottom 25
	preserve
	keep if date >= mdy(3,15,2020) & date < mdy(5,1,2020)

	bysort `unit': egen mean_log_beta = mean(log_beta_t_6) 
	su mean_log_beta if date == mdy(4,30,2020), d
	local median = `r(p50)'
	drop if mean_log_beta < `r(p75)' & mean_log_beta > `r(p25)'
	gen over = (mean_log_beta > `median')

	collapse (mean) `outcomes' delta_log_visits *fe log_pop_density, by(over)

	tsset over
	foreach v of varlist `outcomes' {
		gen d_`v' = `v' - l.`v'
	}
	keep d_*
	keep if _n == 2

	outsheet using "output/additive_decomposition_top_bot_quart.txt", replace

	restore

	* Top 10/Bottom 10
	preserve
	keep if date >= mdy(3,15,2020) & date < mdy(5,1,2020)

	bysort `unit': egen mean_log_beta = mean(log_beta_t_6) 
	su mean_log_beta if date == mdy(4,30,2020), d
	local median = `r(p50)'
	drop if mean_log_beta < `r(p90)' & mean_log_beta > `r(p10)'
	gen over = (mean_log_beta > `median')

	collapse (mean) `outcomes' delta_log_visits *fe log_pop_density, by(over)

	tsset over
	foreach v of varlist `outcomes' {
		gen d_`v' = `v' - l.`v'
	}
	keep d_*
	keep if _n == 2

	outsheet using "output/additive_decomposition_top_bot_dec.txt", replace

	restore

end


*-------------------------------------------------------------------------------------------------
* Construct a program to compute cases given beta
*-------------------------------------------------------------------------------------------------

cap program drop compute_cases
program define compute_cases
	syntax [, suffix(string) gam(real 25) beta(varlist)]
	
	gen new_cases`suffix' = cases - l_cases if t == 1
	gen I_t`suffix'       = cases           if t == 1
	gen cases`suffix'     = cases           if t == 1
	
	levelsof t, local(levels)
	foreach x of local levels {
		if `x' != 1 {
			replace new_cases`suffix' = l.`beta' * l.I_t`suffix' * (pop - l.cases`suffix') / pop                            if t == `x'
			replace cases`suffix'     = new_cases`suffix' + l.cases`suffix'                  if t == `x'
			replace I_t`suffix'       = new_cases`suffix' + (1 - `gam') * l.I_t`suffix'	     if t == `x'
		}
	}
end




cap program drop get_scatter_data
program define get_scatter_data
	syntax [ , unit(string)]


	* Fixed effects already have constant in them
	gen pred_log_beta_full_fe = ${Lambda_0} * delta_log_visits + fe            + date_val_add
	gen pred_log_beta_pred_fe = ${Lambda_0} * delta_log_visits + lasso_pred_fe + date_val_add

	* By CSA
	preserve
	keep if date >= mdy(3,15,2020) & date <= mdy(5,1,2020)

	collapse (mean) log_beta_t_6 pred_log_beta* (max) pop fe lasso_pred_fe, by(`unit' csatitle first_day_order_sip)
	collapse (rawsum) pop (mean) log_beta_t_6 pred_log_beta* fe lasso_pred_fe [aw=pop], by(csatitle)
	
	su pop, d
	gen top_25 = (pop > `r(p75)')

	gen new_label = ""
	replace new_label = "Atlanta" if csatitle == "Atlanta--Athens-Clarke County--Sandy Springs, GA"
	replace new_label = "Dallas"  if csatitle == "Dallas-Fort Worth, TX-OK"
	replace new_label = "NYC"     if csatitle == "New York-Newark, NY-NJ-CT-PA"
	replace new_label = "Denver"  if csatitle == "Denver-Aurora, CO"
	replace new_label = "Boston"  if csatitle == "Boston-Worcester-Providence, MA-RI-NH-CT"
	replace new_label = "Seattle" if csatitle == "Seattle-Tacoma, WA"
	replace new_label = "Orlando" if csatitle == "Orlando-Deltona-Daytona Beach, FL"
	replace new_label = "LA"      if csatitle == "Los Angeles-Long Beach, CA"
	replace new_label = "Houston" if csatitle == "Houston-The Woodlands, TX"
	replace new_label = "Cleveland" if csatitle == "Cleveland-Akron-Canton, OH"
	replace new_label = "SF"        if csatitle == "San Jose-San Francisco-Oakland, CA"
	replace new_label = "Detroit"   if csatitle == "Detroit-Warren-Ann Arbor, MI"
	replace new_label = "Charlotte" if csatitle == "Charlotte-Concord, NC-SC"
	replace new_label = "Chicago"   if csatitle == "Chicago-Naperville, IL-IN-WI"
	replace new_label = "Miami"     if csatitle == "Miami-Fort Lauderdale-Port St. Lucie, FL"
	replace new_label = "Minneapolis" if csatitle == "Minneapolis-St. Paul, MN-WI"
	replace new_label = "Philly"      if csatitle == "Philadelphia-Reading-Camden, PA-NJ-DE-MD"
	replace new_label = "Portland"    if csatitle == "Portland-Vancouver-Salem, OR-WA"
	replace new_label = "DC"          if csatitle == "Washington-Baltimore-Arlington, DC-MD-VA-WV-PA"

	sort csatitle 
	bysort csatitle: gen number = _n
	bysort csatitle: egen max_number = max(number)
	tostring number, replace
	replace number = "" if max_number == 1
	
	export delimited "output/scatter_data.csv", replace
	restore
end
