library(ggplot2)
library(ggrepel)
library(tidyr)
library(dplyr)

data        <- read.csv("output/scatter_data.csv", stringsAsFactors = F)
data$top_25 <- as.numeric(data$top_25 > 0)

# https://stackoverflow.com/questions/40542685/how-to-jitter-remove-overlap-for-geom-text-labels
# https://stackoverflow.com/questions/15015356/how-to-do-selective-labeling-with-ggplot-geom-point
# https://stackoverflow.com/questions/15633714/adding-a-regression-line-on-a-ggplot

data %>%
  ggplot(aes(x = lasso_pred_fe,
             y = fe)) +
  # 45 degree line
  geom_abline(intercept = 0, slope = 1, color = 'black') +
  geom_point(aes(shape = factor(top_25),
                 size = pop,
                 alpha = 0.75),
             show.legend = FALSE) +
  # empty circle marks CSAs not in top 25 
  scale_shape_manual(values = c(1, 16), guide = FALSE) + 
  scale_size_area(guide = FALSE) + 
  geom_smooth(method='lm', formula = y~x, 
              se = F, 
              colour = 'black',
              linetype = 'dashed',
              size = 0.65) +
  geom_text_repel(data = subset(data, top_25 == 1), 
                  aes(lasso_pred_fe, 
                      fe, 
                      label = new_label),
                  size = 3) + 
  ylab('Estimated Log Contact Rate FE') + 
  xlab('Predicted Log Contact Rate FE') +
  xlim(-1.5, 1.5) + ylim(-4, 2) + 
  theme_bw() + 
  theme(text = element_text(family = 'serif'), 
        axis.text = element_text(family = 'serif', size=14),
        axis.title.y = element_text(family = 'serif', size=14), 
        axis.title.x = element_text(family = 'serif', size=14), 
        axis.text.x = element_text(family = 'serif', size=14), 
        axis.text.y = element_text(family = 'serif', size=14)) -> p

ggsave("output/gg_scatter_lasso_predicted.pdf", plot = p, width = 11, height = 11)
