library(dplyr)
library(readr)
library(tidyr)

write_gslab_table <- function(TABLE, output, header){
  write.table(TABLE, file = output, row.names = FALSE, col.names = FALSE, sep = "\t")
  table <- read_file(output) # http://stackoverflow.com/questions/9068397/import-text-file-as-single-character-string
  table <- sprintf("%s\n%s", header, gsub('"', '', table))
  write_file(table, output)
}

data <- read.csv("output/csa_value_add_means.txt", sep = "\t")

data %>%
  mutate(date = as.Date(date, format = '%d%b%Y')) %>%
  select(-date, -pop) %>%
  group_by(csa_order_date) %>%
  summarize_all(~ mean(., na.rm = TRUE)) -> csa_means

csa_means %>%
  select(-csa_order_date) %>%
  summarize_all(~ var(., na.rm = TRUE)) %>%
  pivot_longer(cols = colnames(.), 
               names_to = 'contributor',
               values_to = 'variance') -> variances

contact_rate_variance <- variances %>% filter(contributor == 'log_beta_t_6') %>% pull(variance)

variances %>% 
  mutate(share_of_variance = ifelse(contributor == 'log_beta_t_6', variance,
                                    variance/contact_rate_variance)) %>%
  as.matrix -> variance_decomp_table

write_gslab_table(variance_decomp_table[, 3], "output/var_decomp_table.txt", 
                  "<tab:var_decomp_table>")

