clear all
set maxvar 20000
adopath + "../lib/ado"
set scheme bg_5by8
global optionshealth "ylabel(-2(0.5)2) xlabel(-21(7)21) xmtick(##7) legend(off)"

use "input/event_study_input_data.dta", clear
keep if date <= td(20apr2020)

replace cases     = 0 if cases     == .
replace deaths    = 0 if deaths    == .
replace new_tests = 0 if new_tests == .

* Collapse and Clean
collapse (sum) visits cases deaths new_tests pop (mean) order_sip, by(statename date)
keep if statename != ""

egen state_id = group(statename)
xtset state_id date

bysort state_id: egen temp = min(date) if order_sip == 1
bysort state_id: egen first_day_order_sip = max(temp)
drop temp

g event_day=date-first_day_order_sip
g treatment=~mi(event_day)

xtset state_id date
foreach v in cases deaths {
	replace `v'  = 0 if `v' == .
	replace `v'  = l.`v' if `v' < l.`v' & l.`v' != .
	gen l_`v'    = l.`v'
}

xtset state_id date
gen log_cases      = log(cases)

* Dave et al Replications
eventplot log_cases lead* lag* i.state_id##c.date [aw=pop] if date <= td(20apr2020), ///
	absorb(state_id date) treatvar(treatment) eventtime(event_day) ///
	leads(21) lags(21) omit(1) clustervar(state_id) ${optionshealth} ///
	title("") output("output/replication/dave_et_al_individual")
	
eventplot log_cases lead* lag* i.state_id##c.date [aw=pop] if date <= td(20apr2020), ///
	absorb(state_id date) treatvar(treatment) eventtime(event_day) ///
	leads(14) lags(21) omit(1) clustervar(state_id) ${optionshealth} ///
	title("") output("output/replication/dave_et_al_individual_14")

eventplot log_cases lead* lag* i.state_id##c.date [aw=pop] if date <= td(20apr2020), ///
	absorb(state_id date) treatvar(treatment) eventtime(event_day) ///
	leads(7) lags(21) omit(1) clustervar(state_id) ${optionshealth} ///
	title("") output("output/replication/dave_et_al_individual_short")
	
