clear all
set maxvar 20000
adopath + "../lib/ado"
set scheme bg_5by8
global options1 "ylabel(-0.3(0.1)0.3) xlabel(-21(7)21) xmtick(##7) legend(off)"


foreach suff in "" "plac_" {

	import delimited output/`suff'simulated_data.csv, clear
	gen county_id = n

	gen order_sip = 0
	replace order_sip = 1 if t >= (treated + 1)
	g event_day=t-(treated + 1)
	g treatment=~mi(event_day)

	xtset county_id t

	cap drop beta_t
	cap drop I_t
	local gamma = .1
	local gamma_small = .05
	local gamma_large = .2
	gen beta_t = (f.c - c) / c if t == 1
	gen I_t = c if t == 1
	gen I_t_sm = c if t == 1
	gen I_t_lg = c if t == 1
	forvalues x = 2/150 {
		replace beta_t = (f.c - c) / ((1 + l.beta_t - `gamma') * l.I_t) if t == `x'
		replace I_t = (c - l.c) + (1 - `gamma') * l.I_t	 if t == `x'
		replace I_t_sm = (c - l.c) + (1 - `gamma_small') * l.I_t_sm	 if t == `x'
		replace I_t_lg = (c - l.c) + (1 - `gamma_large') * l.I_t_lg	 if t == `x'
	}

	gen log_I_t = log(I_t)
	gen log_I_t_sm = log(I_t_sm)
	gen log_I_t_lg = log(I_t_lg)

	gen log_new_cases = log(f.c - c)
	gen log_cases = log(c)

	* Creat event_window indicators
	foreach e in 7 14 21 {
		gen event_window_`e' = 0
		replace event_window_`e' = 1 if (event_day >= -(`e' - 1) & event_day <= 20 & event_day != .)	
	}

	if "`suff'" == "plac_" {
		local val = "0"
	}
	if "`suff'" != "plac_" {
		local val = "-.1"
	}
	
	* Event study plots
	eventplot log_new_cases lead* lag* event_window_21 [aw=pop], ///
		absorb(t) treatvar(treatment) eventtime(event_day) ///
		leads(21) lags(21) omit(1) clustervar(county_id) ${options1} ///
		title("{&tau}=`val'") output("output/`suff'log_new_cases_no_log_I")
	
	eventplot log_new_cases lead* lag* log_I_t event_window_21 [aw=pop], ///
		absorb(t) treatvar(treatment) eventtime(event_day) ///
		leads(21) lags(21) omit(1) clustervar(county_id) ${options1} ///
		title("{&tau}=`val'") output("output/`suff'log_new_cases")

	eventplot log_new_cases lead* lag* log_I_t [aw=pop], ///
		absorb(county_id t) treatvar(treatment) eventtime(event_day) ///
		leads(21) lags(21) omit(1) clustervar(county_id) ${options1} ///
		title("{&tau}=`val'") output("output/`suff'log_new_cases_geography_fe")

	eventplot log_new_cases lead* lag* log_I_t_sm event_window_21 [aw=pop], ///
		absorb(t) treatvar(treatment) eventtime(event_day) ///
		leads(21) lags(21) omit(1) clustervar(county_id) ${options1} ///
		title("{&tau}=`val'") output("output/`suff'log_new_cases_small_gamma")
	
	eventplot log_new_cases lead* lag* log_I_t_lg event_window_21 [aw=pop], ///
		absorb(t) treatvar(treatment) eventtime(event_day) ///
		leads(21) lags(21) omit(1) clustervar(county_id) ${options1} ///
		title("{&tau}=`val'") output("output/`suff'log_new_cases_large_gamma")

	eventplot log_cases lead* lag* i.county_id##c.t [aw=pop], ///
		absorb(county_id t) treatvar(treatment) eventtime(event_day) ///
		leads(21) lags(21) omit(1) clustervar(county_id) ${options1} ///
		title("{&tau}=`val'") output("output/`suff'log_cases_geography_fe_with_linear_trends_long")
}
