###################
### ENVIRONMENT ###
###################
import git
import imp
import os
import yaml

# LOAD GSLAB MAKE
ROOT = git.Repo('.', search_parent_directories = True).working_tree_dir 
f, path, desc = imp.find_module('gslab_make', [os.path.join(ROOT, 'lib')]) 
gs = imp.load_module('gslab_make', f, path, desc)

# SET DEFAULT PATHS
PATHS = {
    'config'          : '../config.yaml',
    'config_user'     : '../config_user.yaml',
    'input_dir'       : 'input', 
    'external_dir'    : 'external',
    'output_dir'      : 'output/',
    'output_local_dir': ['output_local'],       # Optional; include any local directories with outputs
    'pdf_dir'         : 'output/',
    'makelog'         : 'log/make.log',         # Set to '' to avoid writing log
    'output_statslog' : 'log/output_stats.log', # Set to '' to avoid writing log
    'output_headslog' : 'log/output_heads.log', # Set to '' to avoid writing log
    'source_maplog'   : 'log/source_map.log',   # Set to '' to avoid writing log
    'source_statslog' : 'log/source_stats.log', # Set to '' to avoid writing log
    'source_headslog' : 'log/source_heads.log'  # Set to '' to avoid writing log
}

### SET PATH MAPPINGS
PATH_MAPPINGS = { 
    'root': ROOT
}

### LOAD CONFIG USER 
gs.update_executables(PATHS)
PATH_MAPPINGS = gs.update_mappings(PATHS, PATH_MAPPINGS)

############
### MAKE ###
############

### START MAKE
gs.remove_dir(['input', 'external'])
gs.clear_dir(['output', 'log'])
gs.start_makelog(PATHS)

### GET INPUT FILES 
inputs = gs.copy_inputs(PATHS, ['input.txt'], PATH_MAPPINGS)
externals = gs.copy_externals(PATHS, ['external.txt'], PATH_MAPPINGS)
gs.write_source_logs(PATHS, inputs + externals)
gs.get_modified_sources(PATHS, inputs + externals)

### FILL TABLES             
gs.tablefill(template = 'code/health_reg_table.lyx', 
             input    = 'input/event_studies/csa/table_agg_reg.txt', 
             output   = 'output/health_reg_table_filled.lyx')

gs.tablefill(template = 'code/policy_source_table.lyx', 
             input    = 'input/descriptive/policy_source_table.txt', 
             output   = 'output/policy_source_table_filled.lyx')

gs.tablefill(template = 'code/table_decomp.lyx', 
             input    = 'input/event_studies/decomp/table_decomp.txt', 
             output   = 'output/decomposition_table_filled.lyx')

gs.tablefill(template = 'code/table_decomp_appendix.lyx', 
             input    = 'input/event_studies/decomp/table_decomp_appendix.txt', 
             output   = 'output/decomposition_table_appendix_filled.lyx')

gs.tablefill(template = 'code/var_decomp_table.lyx', 
             input    = 'input/geo_variation/var_decomp_table.txt', 
             output   = 'output/var_decomp_table_filled.lyx')

gs.tablefill(template = 'code/add_decomp_table.lyx', 
             input    = 'input/geo_variation/add_decomp_table.txt', 
             output   = 'output/add_decomp_table_filled.lyx')

gs.tablefill(template = 'code/table_summary.lyx', 
             input    = 'input/geo_variation/summary_stats.txt', 
             output   = 'output/table_summary_filled.lyx')

gs.tablefill(template = 'code/text_tables.lyx', 
             input    = " ".join(['input/event_studies/tables/visits.txt',
                                  'input/event_studies/tables/total_spend.txt',
                                  'input/event_studies/tables/count_hours.txt',
                                  'input/event_studies/tables/num_transactions.txt',
                                  'input/event_studies/tables/sum_hours.txt',
                                  'input/event_studies/tables/sum_wages.txt',
                                  'input/event_studies/tables/visits_cty.txt',
                                  'input/event_studies/tables/total_spend_cty.txt',
                                  'input/event_studies/tables/count_hours_cty.txt',
                                  'input/event_studies/tables/visits_open.txt',
                                  'input/event_studies/tables/total_spend_open.txt',
                                  'input/event_studies/tables/count_hours_open.txt',
                                  'input/event_studies/decomp/table_decomp_pct.txt',
                                  'input/event_studies/decomp/table_contact_pct.txt']),
             output   = 'output/text_tables_filled.lyx')


### RUN SCRIPTS
gs.run_lyx(PATHS, program = 'code/VirusPolicy.lyx')
gs.run_lyx(PATHS, program = 'code/text.lyx')

### LOG OUTPUTS
gs.log_files_in_output(PATHS)

### CHECK FILE SIZES
gs.check_module_size(PATHS)

### END MAKE
gs.end_makelog(PATHS)